@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from django.db import models, migrations
 import django.db.models.deletion
-import ditto.core.models
 import taggit.managers
+from django.db import migrations, models
+
+import ditto.core.models
 
 
 class Migration(migrations.Migration):
