@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from django.db import models, migrations
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
@@ -12,7 +12,8 @@ class Migration(migrations.Migration):
 
     operations = [
         migrations.AlterModelOptions(
-            name="photo", options={"ordering": ("-post_time",)},
+            name="photo",
+            options={"ordering": ("-post_time",)},
         ),
         migrations.AlterField(
             model_name="photo",
