@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from django.db import models, migrations
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
@@ -12,10 +12,14 @@ class Migration(migrations.Migration):
 
     operations = [
         migrations.RenameField(
-            model_name="photo", old_name="height_mp4_hd", new_name="hd_mp4_height",
+            model_name="photo",
+            old_name="height_mp4_hd",
+            new_name="hd_mp4_height",
         ),
         migrations.RenameField(
-            model_name="photo", old_name="width_mp4_hd", new_name="hd_mp4_width",
+            model_name="photo",
+            old_name="width_mp4_hd",
+            new_name="hd_mp4_width",
         ),
         migrations.RenameField(
             model_name="photo",
@@ -28,33 +32,103 @@ class Migration(migrations.Migration):
             new_name="mobile_mp4_width",
         ),
         migrations.RenameField(
-            model_name="photo", old_name="height_mp4_site", new_name="site_mp4_height",
+            model_name="photo",
+            old_name="height_mp4_site",
+            new_name="site_mp4_height",
         ),
         migrations.RenameField(
-            model_name="photo", old_name="width_mp4_site", new_name="site_mp4_width",
+            model_name="photo",
+            old_name="width_mp4_site",
+            new_name="site_mp4_width",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_b",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_c",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_h",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_k",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_m",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_n",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_o",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_t",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_video_original",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="height_z",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_b",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_c",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_h",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_k",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_m",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_n",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_o",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_t",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_video_original",
+        ),
+        migrations.RemoveField(
+            model_name="photo",
+            name="width_z",
         ),
-        migrations.RemoveField(model_name="photo", name="height",),
-        migrations.RemoveField(model_name="photo", name="height_b",),
-        migrations.RemoveField(model_name="photo", name="height_c",),
-        migrations.RemoveField(model_name="photo", name="height_h",),
-        migrations.RemoveField(model_name="photo", name="height_k",),
-        migrations.RemoveField(model_name="photo", name="height_m",),
-        migrations.RemoveField(model_name="photo", name="height_n",),
-        migrations.RemoveField(model_name="photo", name="height_o",),
-        migrations.RemoveField(model_name="photo", name="height_t",),
-        migrations.RemoveField(model_name="photo", name="height_video_original",),
-        migrations.RemoveField(model_name="photo", name="height_z",),
-        migrations.RemoveField(model_name="photo", name="width",),
-        migrations.RemoveField(model_name="photo", name="width_b",),
-        migrations.RemoveField(model_name="photo", name="width_c",),
-        migrations.RemoveField(model_name="photo", name="width_h",),
-        migrations.RemoveField(model_name="photo", name="width_k",),
-        migrations.RemoveField(model_name="photo", name="width_m",),
-        migrations.RemoveField(model_name="photo", name="width_n",),
-        migrations.RemoveField(model_name="photo", name="width_o",),
-        migrations.RemoveField(model_name="photo", name="width_t",),
-        migrations.RemoveField(model_name="photo", name="width_video_original",),
-        migrations.RemoveField(model_name="photo", name="width_z",),
         migrations.AddField(
             model_name="photo",
             name="large_1600_height",
