@@ -1,5 +1,5 @@
 from django.conf import settings
-from django.core.checks import register, Error, Tags
+from django.core.checks import Error, Tags, register
 
 
 @register(Tags.compatibility)
