@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from django.db import models, migrations
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
@@ -11,7 +11,10 @@ class Migration(migrations.Migration):
     ]
 
     operations = [
-        migrations.RemoveField(model_name="bookmark", name="shared",),
+        migrations.RemoveField(
+            model_name="bookmark",
+            name="shared",
+        ),
         migrations.AlterField(
             model_name="bookmark",
             name="raw",
