@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from django.db import models, migrations
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
@@ -12,10 +12,12 @@ class Migration(migrations.Migration):
 
     operations = [
         migrations.AlterModelOptions(
-            name="account", options={"ordering": ["username"]},
+            name="account",
+            options={"ordering": ["username"]},
         ),
         migrations.AlterModelOptions(
-            name="bookmark", options={"ordering": ["-post_time"]},
+            name="bookmark",
+            options={"ordering": ["-post_time"]},
         ),
         migrations.AlterField(
             model_name="account",
